%define pypi_name	dulwich

%bcond_with doc

Name:		python-%{pypi_name}
Version:	0.23.0
Release:	%mkrel 1
Summary:	Python implementation of the Git file formats and protocols
License:	GPLv2
Group:		Development/Python
Url:		https://pypi.org/project/dulwich
Source0:	%{pypi_source}
BuildRequires:	git-core
BuildRequires:	pkgconfig(python3)
BuildRequires:	rust-packaging >= 24

# docs
%if %{with doc}
BuildRequires:	python3dist(sphinx)
BuildRequires:	python3dist(sphinx-epytext)
BuildRequires:	python3dist(paramiko)
BuildRequires:	python3dist(gevent)
BuildRequires:	python3dist(fastimport)
BuildRequires:	python3dist(geventhttpclient)
%endif

# for tests
BuildRequires:	gnupg2

%description
Dulwich is a pure-Python implementation of the Git file formats and protocols.

%package -n	python3-%{pypi_name}
Summary:	Python 3 implementation of the Git file formats and protocols
Group:		Development/Python
%{?python_provide:%python_provide python3-%{pypi_name}}

%description -n	python3-%{pypi_name}
Dulwich is a pure-Python implementation of the Git file formats and protocols.

%pyproject_extras_subpkg -n python3-%{pypi_name} fastimport https pgp paramiko

%prep
%autosetup -p1 -n %{pypi_name}-%{version}
%cargo_prep

%generate_buildrequires
%pyproject_buildrequires -t
%cargo_generate_buildrequires

%build
%pyproject_wheel

# docs
%if %{with doc}
%make_build html -C docs
# doc build leftovers
rm -rf docs/build/html/.{doctrees,buildinfo}
%endif

%install
%pyproject_install
%pyproject_save_files dulwich

%check
#tox

%files -n python3-%{pypi_name} -f %{pyproject_files}
%license COPYING
%doc NEWS README.rst
%if %{with doc}
%doc docs/build/html
%endif
%{_bindir}/dul-receive-pack
%{_bindir}/dul-upload-pack
%{_bindir}/dulwich
%exclude %{python3_sitearch}/%{pypi_name}/tests*


%changelog
* Wed Jun 25 2025 papoteur <papoteur> 0.23.0-1.mga10
+ Revision: 2194543
- new version 0.23.0

* Tue Feb 25 2025 wally <wally> 0.22.7-3.mga10
+ Revision: 2152547
- rebuild for python3.13

* Sun Feb 02 2025 wally <wally> 0.22.7-2.mga10
+ Revision: 2144666
- add fastimport, https, pgp, and paramiko extras subpkgs

* Sun Feb 02 2025 wally <wally> 0.22.7-1.mga10
+ Revision: 2144661
- new version 0.22.7
- fix rust crates build and make debug pkgs available again

* Sun Feb 02 2025 daviddavid <daviddavid> 0.22.1-1.mga10
+ Revision: 2144594
- new version: 0.22.1

* Sat Dec 09 2023 wally <wally> 0.21.7-1.mga10
+ Revision: 2016326
- new version 0.21.7

* Tue Oct 17 2023 papoteur <papoteur> 0.21.6-1.mga10
+ Revision: 1998080
- new 0.21.6

* Sun Jan 22 2023 wally <wally> 0.21.2-1.mga9
+ Revision: 1934813
- new version 0.21.2

* Thu Sep 29 2022 neoclust <neoclust> 0.20.46-1.mga9
+ Revision: 1893251
- New version 0.20.46

* Tue Sep 06 2022 neoclust <neoclust> 0.20.45-1.mga9
+ Revision: 1884547
- New version 0.20.45
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Tue Feb 15 2022 tv <tv> 0.20.25-2.mga9
+ Revision: 1775631
- Disable tests for now
- Rebuild for python-3.10

* Sat Aug 28 2021 wally <wally> 0.20.25-1.mga9
+ Revision: 1743177
- new version 0.20.25

* Fri Jul 16 2021 wally <wally> 0.20.23-1.mga9
+ Revision: 1736225
- new version 0.20.23

* Fri Mar 19 2021 neoclust <neoclust> 0.20.19-2.mga9
+ Revision: 1705006
- Rebuild against python 3.9

* Tue Mar 02 2021 guillomovitch <guillomovitch> 0.20.19-1.mga9
+ Revision: 1696406
- new version 0.20.19

* Sat Nov 28 2020 guillomovitch <guillomovitch> 0.20.14-1.mga8
+ Revision: 1649876
- new version 0.20.14

* Sun Nov 08 2020 guillomovitch <guillomovitch> 0.20.11-1.mga8
+ Revision: 1643741
- new version 0.20.11

* Mon Sep 14 2020 guillomovitch <guillomovitch> 0.20.6-1.mga8
+ Revision: 1626337
- new version 0.20.6

* Wed Jun 10 2020 daviddavid <daviddavid> 0.20.2-1.mga8
+ Revision: 1591649
- new version: 0.20.2

* Tue Apr 28 2020 daviddavid <daviddavid> 0.19.16-1.mga8
+ Revision: 1572821
- new version: 0.19.16

* Thu Feb 20 2020 umeabot <umeabot> 0.19.15-2.mga8
+ Revision: 1546121
- Mageia 8 Mass Rebuild

* Fri Jan 31 2020 daviddavid <daviddavid> 0.19.15-1.mga8
+ Revision: 1486040
- new version: 0.19.15

* Fri Jan 31 2020 daviddavid <daviddavid> 0.19.14-1.mga8
+ Revision: 1485940
- new version: 0.19.14

* Thu Sep 05 2019 wally <wally> 0.19.13-1.mga8
+ Revision: 1437564
- new version 0.19.13
- drop python2 support
- rebuild for python3.8

* Sun Aug 18 2019 wally <wally> 0.19.12-1.mga8
+ Revision: 1429727
- new version 0.19.12
- update sphinx BRs

* Sun Apr 21 2019 wally <wally> 0.19.11-1.mga7
+ Revision: 1394312
- new version 0.19.11

* Mon Jan 07 2019 kekepower <kekepower> 0.19.9-1.mga7
+ Revision: 1351279
- Update to version 0.19.9

* Sun Sep 23 2018 umeabot <umeabot> 0.19.2-2.mga7
+ Revision: 1300471
- Mageia 7 Mass Rebuild

* Mon Apr 23 2018 shlomif <shlomif> 0.19.2-1.mga7
+ Revision: 1222030
- New version 0.19.2 w hg-git fix

* Thu Apr 05 2018 kekepower <kekepower> 0.19.0-1.mga7
+ Revision: 1215384
- Update to version 0.19.0
- Renamed python-dulwich to python2-dulwich
- Use python_provide

* Sat Aug 05 2017 pterjan <pterjan> 0.12.0-2.mga7
+ Revision: 1135407
- Rebuild for python 3.6

* Fri Feb 05 2016 daviddavid <daviddavid> 0.12.0-1.mga6
+ Revision: 939302
- new version: 0.12.0
- add python3 package

* Fri Oct 16 2015 philippem <philippem> 0.11.2-1.mga6
+ Revision: 892207
- update to 0.11.2

* Tue Mar 24 2015 philippem <philippem> 0.10.0-2.mga5
+ Revision: 819178
- update to 0.10.0 fix  CVE-2014-9706 and CVE-2015-0838 mga#15558

* Mon Mar 23 2015 philippem <philippem> 0.9.9-2.mga5
+ Revision: 819136
- update to 0.9.9 fix  CVE-2014-9706 and CVE-2015-0838 mga#15558

* Wed Oct 15 2014 umeabot <umeabot> 0.9.7-4.mga5
+ Revision: 740682
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.9.7-3.mga5
+ Revision: 728379
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.9.7-2.mga5
+ Revision: 688011
- Mageia 5 Mass Rebuild

* Mon Jun 23 2014 philippem <philippem> 0.9.7-1.mga5
+ Revision: 638933
- update to 0.9.7
+ pterjan <pterjan>
- Rebuild for new Python

* Wed Mar 05 2014 philippem <philippem> 0.9.5-1.mga5
+ Revision: 600134
- Update to 0.9.5

* Tue Oct 22 2013 umeabot <umeabot> 0.9.0-3.mga4
+ Revision: 543355
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 0.9.0-2.mga4
+ Revision: 498454
- Rebuild to add different pythonegg provides for python 2 and 3

* Thu Jul 04 2013 philippem <philippem> 0.9.0-1.mga4
+ Revision: 450242
- Update to 0.9.0

* Sun Jan 13 2013 umeabot <umeabot> 0.8.5-2.mga3
+ Revision: 378773
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Mon Aug 13 2012 lebedov <lebedov> 0.8.5-1.mga3
+ Revision: 281123
- Update to 0.8.5.

* Sun Jan 22 2012 lebedov <lebedov> 0.8.3-1.mga2
+ Revision: 199653
- Update to 0.8.3.

* Mon Dec 19 2011 lebedov <lebedov> 0.8.2-1.mga2
+ Revision: 184080
- Update to 0.8.2.

* Wed Nov 30 2011 lebedov <lebedov> 0.8.1-1.mga2
+ Revision: 174435
- Update to 0.8.1.

* Tue Sep 20 2011 lebedov <lebedov> 0.8.0-1.mga2
+ Revision: 146150
- imported package python-dulwich

